# -*- encoding: utf-8 -*-
# stub: fresh-auth 0.0.1 ruby lib

Gem::Specification.new do |s|
  s.name = "fresh-auth".freeze
  s.version = "0.0.1"

  s.required_rubygems_version = Gem::Requirement.new(">= 0".freeze) if s.respond_to? :required_rubygems_version=
  s.require_paths = ["lib".freeze]
  s.authors = ["Isaac Betesh".freeze]
  s.date = "2012-09-04"
  s.description = "# Fresh::Auth\n\nThis gem makes it really, REALLY easy to use the Freshbooks API.  It couldn't be easier.\n\nWith only 3 functions you'll ever need to use, and only 2 required configuration values, it can't get any easier.\n\n## Installation\n\nAdd this line to your application's Gemfile:\n    gem 'fresh-auth'\nAnd then execute:\n    $ bundle\nOr install it yourself as:\n    $ gem install fresh-auth\n\n## Usage\n\n### Configuration:\n\nYou must define your Freshbooks subdomain and your OAuth Secret in your application code before using Fresh::Auth.  For Ruby on Rails apps, a new file at config/initializers/fresh-auth.rb would be appropriate.\n\nYour configuration file should look like this (you fill in the three empty strings):\n\n    Fresh::Auth.configure do |config|\n\n      # The part of your login url between 'http://' and '.freshbooks.com'\n      config.url.subdomain = \"\"\n\n      # Under 'My Account' (on the top right when you're logged into Freshbooks)\n      #   -> 'Freshbooks API' -> 'OAuth Developer Access' -> 'OAuth Secret'\n      # You'll need to request this from Freshbooks initially.\n      config.oauth_secret = \"\"\n\n      # Optional.  Any string of your choice.  Be creative or check out http://www.thebitmill.com/tools/password.html\n      config.nonce_salt = \"\"\n    end\n\nFear not: If you try to use Fresh::Auth without configuring it first, an exception will be thrown that clearly describes the problem.\n\n### Public API:\n\nThere are two modules in this API: Fresh::Auth::Authentication and Fresh::Auth::Api\n\n#### Fresh::Auth::Authentication\n\nThis module authenticates you with Freshbooks, storing the authentication in an array called `session`.  This integrates seamlessly with Ruby on Rails' controller environment.  If you're using some framework other than Ruby on Rails, make sure to define session in your class before including the Authentication module.  This isn't recommended because your class will also need to define other objects called `params` and `request` and implement a `redirect_to` method.  It gets complicated.  Better leave it to Rails to handle this for you.\n\nThe only public function of this module is AuthenticateWithFreshbooks.\n\nTo use it, just add the following line of code to your controller:\n`\ninclude Fresh::Auth::Authentication\n`\n\nThen, the following line of code authenticates with Freshbooks from any method in your controller:\n`\nAuthenticateWithFreshbooks()\n`\n\nNote that, after authenticating with Freshbooks, the user will be redirected back to the same path using HTTP GET, so make sure the resource supports HTTP GET and that in the business logic executed on GET, AuthenticateWihFreshbooks() is called.\n\n#### Fresh::Auth::Api\n\nOnce you've authenticated, you want to send XML requests to Freshbooks.  The first step is preparing the XML with Fresh::Auth::Api.GenerateXml, which you'll supply with a block that defines all the nested XML that you want in your request.  GenerateXml also takes two arguments before the block: the class and method that you want to call.\n\nFirst, in your controller:\n`include Fresh::Auth::Api`\n\nThen, in some method in that controller:\n\n    my_xml = GenerateXml :invoice, :update do |xml|\n      xml.client_id 20\n      xml.status 'sent'\n      xml.notes 'Pick up the car by 5'\n      xml.terms 'Cash only'\n      xml.lines {\n        xml.line {\n          xml.name 'catalytic converter'\n          xml.quantity 1\n          xml.unit_cost 450\n          xml.type 'Item'\n        }\n        xml.line {\n          xml.name 'labor'\n          xml.quantity 1\n          xml.unit_cost 60\n          xml.type 'Time'\n        }\n      }\n    end\n\nOk, you created the XML.  Now you want to send it.  Sounds pretty complicated, right?  Not at all! Ready?  Let's go!\n\n`_response = PostToFreshbooksApi my_xml`\n\nNow, are you wondering what's in `_response`?  I'll tell you shortly, but before we discuss that, we have to know about the exception that PostToFreshbooksApi might raise.  It raises a detailed error message if the response status is not 'ok'.  Makes sense, right?\n\nNow, you still want to know what's in `_response`?  Oh, nothing fancy.  Just a Nokogiri XML object, representing the root element of the xml response.  Could this get any easier?\n\n## Contributing\n\n1. Fork it\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Commit your changes (`git commit -am 'Added some feature'`)\n4. Push to the branch (`git push origin my-new-feature`)\n5. Create new Pull Request\n".freeze
  s.email = ["iybetesh@gmail.com".freeze]
  s.licenses = ["MIT".freeze]
  s.rubygems_version = "3.2.22".freeze
  s.summary = "Authenticates with the Freshbooks API and stores the authentication in a session with minimal configuration".freeze

  s.installed_by_version = "3.2.22" if s.respond_to? :installed_by_version

  if s.respond_to? :specification_version then
    s.specification_version = 3
  end

  if s.respond_to? :add_runtime_dependency then
    s.add_runtime_dependency(%q<builder>.freeze, [">= 3.0.0"])
    s.add_runtime_dependency(%q<rest-client>.freeze, [">= 1.6.7"])
    s.add_runtime_dependency(%q<nokogiri>.freeze, [">= 1.5.5"])
  else
    s.add_dependency(%q<builder>.freeze, [">= 3.0.0"])
    s.add_dependency(%q<rest-client>.freeze, [">= 1.6.7"])
    s.add_dependency(%q<nokogiri>.freeze, [">= 1.5.5"])
  end
end
